# <img src="pixelgreat_gui/resources/icon.png" height="20px" alt="Pixelgreat"/> Pixelgreat GUI
### A GUI for [Pixelgreat: A highly realistic RGB pixel filter for Python.](https://github.com/nimaid/pixelgreat)

<p align="center"><img src="docs/example.png" width="800px" alt="Screenshot of the program"/></p>

<p align="center"><a href="https://pypi.org/project/pixelgreat-gui/"><img src="https://pypi.org/static/images/logo-large.9f732b5f.svg" width="200px" alt="pixelgreat on Pypi"></a></p>

## Installation
[Download the latest .exe release here!](https://github.com/nimaid/pixelgreat-gui/releases/latest)
